@@ -254,11 +254,7 @@
     <message>
         <location filename="../mainwindow.ui" line="753"/>
         <source>Clone a mounted live system</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Clone an existing live system</source>
-        <translation type="vanished">Kloniraj obstoječ živi sistem</translation>
+        <translation>Kloniraj priklopljeni živi sistem</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="760"/>
@@ -310,7 +306,7 @@ Počakajte, da se postopek zaključi</translation>
     <message>
         <location filename="../mainwindow.cpp" line="162"/>
         <source>MX Live Usb Maker</source>
-        <translation type="unfinished"></translation>
+        <translation>MX Ustvarjalnik živih usb ključkov</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="333"/>
