@@ -256,10 +256,6 @@
         <source>Clone a mounted live system</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Clone an existing live system</source>
-        <translation type="vanished">複製既有的現場系統</translation>
-    </message>
     <message>
         <location filename="../mainwindow.ui" line="760"/>
         <source>Set up to boot from an encrypted partition, will prompt for pass phrase on first boot</source>
